@@ -27,6 +27,7 @@ from typing import Iterator
 from pytgpt.utils import Optimizers
 from pytgpt.utils import default_path
 from pytgpt.utils import AwesomePrompts
+from pytgpt.utils import RawDog
 from WebChatGPT.console import chat as webchatgpt
 from colorama import Fore
 from colorama import init as init_colorama
@@ -330,6 +331,10 @@ class Main(cmd.Cmd):
         quiet=False,
         chat_completion=False,
         ignore_working=False,
+        rawdog=False,
+        external_exec=False,
+        confirm_script=False,
+        interpreter="python",
         *args,
         **kwargs,
     ):
@@ -342,6 +347,19 @@ class Main(cmd.Cmd):
 
         try:
             getOr = lambda option, default: option if option else default
+
+            if rawdog:
+
+                self.RawDog = RawDog(
+                    quiet=quiet,
+                    external_exec=external_exec,
+                    confirm_script=confirm_script,
+                    interpreter=interpreter,
+                    prettify=True,
+                )
+                intro = self.RawDog.intro_prompt
+                getpass.getuser = lambda: "RawDog"
+
             if provider == "leo":
                 import pytgpt.leo as leo
 
@@ -362,27 +380,6 @@ class Main(cmd.Cmd):
                     act=awesome_prompt,
                 )
 
-            elif provider == "fakeopen":
-                from pytgpt.fakeopen import main
-
-                self.bot = main.FAKEOPEN(
-                    disable_conversation,
-                    max_tokens,
-                    temperature,
-                    top_p,
-                    top_k,
-                    top_p,
-                    getOr(model, main.model),
-                    getOr(auth, main.auth),
-                    timeout,
-                    intro,
-                    filepath,
-                    update_file,
-                    proxies,
-                    history_offset,
-                    awesome_prompt,
-                )
-
             elif provider == "openai":
                 assert auth, "OpenAI API key is required"
                 from pytgpt.openai import main
@@ -465,6 +462,42 @@ class Main(cmd.Cmd):
                     model=getOr(model, phind.default_model),
                 )
 
+            elif provider == "llama2":
+                import pytgpt.llama2.main as llama2
+
+                self.bot = llama2.LLAMA2(
+                    is_conversation=disable_conversation,
+                    max_tokens=max_tokens,
+                    temperature=temperature,
+                    presence_penalty=top_p,
+                    frequency_penalty=top_k,
+                    top_p=top_p,
+                    model=getOr(model, llama2.default_model),
+                    timeout=timeout,
+                    intro=intro,
+                    filepath=filepath,
+                    update_file=update_file,
+                    proxies=proxies,
+                    history_offset=history_offset,
+                    act=awesome_prompt,
+                )
+
+            elif provider == "blackboxai":
+
+                from pytgpt.blackboxai import BLACKBOXAI
+
+                self.bot = BLACKBOXAI(
+                    is_conversation=disable_conversation,
+                    max_tokens=max_tokens,
+                    timeout=timeout,
+                    intro=intro,
+                    filepath=filepath,
+                    update_file=update_file,
+                    proxies=proxies,
+                    history_offset=history_offset,
+                    act=awesome_prompt,
+                )
+
             elif provider in pytgpt.gpt4free_providers:
                 from pytgpt.gpt4free import GPT4FREE
 
@@ -502,6 +535,7 @@ class Main(cmd.Cmd):
         self.disable_stream = False
         self.provider = provider
         self.disable_coloring = False
+        self.rawdog = rawdog
         self.__init_time = time.time()
         self.__start_time = time.time()
         self.__end_time = time.time()
@@ -801,11 +835,21 @@ class Main(cmd.Cmd):
 
     @busy_bar.run()
     def default(self, line, exit_on_error: bool = False):
-        """Chat with ChatGPT"""
+        """Chat with LLM"""
         if not bool(line):
             return
         if line.startswith("./"):
             os.system(line[2:])
+
+        elif self.rawdog:
+            self.__start_time = time.time()
+            busy_bar.start_spinning()
+            ai_response = self.bot.chat(line, stream=False)
+            is_feedback = self.RawDog.main(ai_response)
+            if is_feedback:
+                return self.default(self.bot.chat(is_feedback))
+            busy_bar.stop_spinning()
+
         else:
             self.__start_time = time.time()
             try:
@@ -1091,6 +1135,31 @@ class ChatInteractive:
         is_flag=True,
         help="Ignore working status of the provider",
     )
+    @click.option(
+        "-rd",
+        "--rawdog",
+        is_flag=True,
+        help="Generate and auto-execute Python scripts - (experimental)",
+    )
+    @click.option(
+        "-ex",
+        "--external-exec",
+        is_flag=True,
+        help="RawDog : Execute scripts with system's python interpreter",
+    )
+    @click.option(
+        "-cs",
+        "--confirm-script",
+        is_flag=True,
+        help="RawDog : Give consent to generated scripts prior to execution",
+    )
+    @click.option(
+        "-int",
+        "--interpreter",
+        default="python",
+        help="RawDog : Python's interpreter name",
+        envvar="python_interpreter",
+    )
     @click.help_option("-h", "--help")
     def interactive(
         model,
@@ -1121,6 +1190,10 @@ class ChatInteractive:
         no_coloring,
         chat_completion,
         ignore_working,
+        rawdog,
+        external_exec,
+        confirm_script,
+        interpreter,
     ):
         """Chat with AI interactively (Default)"""
         this.clear_history_file(filepath, new)
@@ -1143,6 +1216,10 @@ class ChatInteractive:
             quiet,
             chat_completion,
             ignore_working,
+            rawdog=rawdog,
+            external_exec=external_exec,
+            confirm_script=confirm_script,
+            interpreter=interpreter,
         )
         busy_bar.spin_index = busy_bar_index
         bot.code_theme = code_theme
@@ -1344,6 +1421,31 @@ class ChatGenerate:
         is_flag=True,
         help="Ignore working status of the provider",
     )
+    @click.option(
+        "-rd",
+        "--rawdog",
+        is_flag=True,
+        help="Generate and auto-execute Python scripts - (experimental)",
+    )
+    @click.option(
+        "-ex",
+        "--external-exec",
+        is_flag=True,
+        help="RawDog : Execute scripts with system's python interpreter",
+    )
+    @click.option(
+        "-cs",
+        "--confirm-script",
+        is_flag=True,
+        help="RawDog : Give consent to generated scripts prior to execution",
+    )
+    @click.option(
+        "-int",
+        "--interpreter",
+        default="python",
+        help="RawDog : Python's interpreter name",
+        envvar="python_interpreter",
+    )
     @click.help_option("-h", "--help")
     def generate(
         model,
@@ -1374,6 +1476,10 @@ class ChatGenerate:
         new,
         with_copied,
         ignore_working,
+        rawdog,
+        external_exec,
+        confirm_script,
+        interpreter,
     ):
         """Generate a quick response with AI"""
         bot = Main(
@@ -1394,6 +1500,10 @@ class ChatGenerate:
             provider,
             quiet,
             ignore_working=ignore_working,
+            rawdog=rawdog,
+            external_exec=external_exec,
+            confirm_script=confirm_script,
+            interpreter=interpreter,
         )
         prompt = prompt if prompt else ""
         copied_placeholder = "{{copied}}"
